v3.0.1
======

Better test coverage. Removed ``Comic.older()``.

v3.0.0
======

Require Python 3.6 or later.

Requests are now cached in ~/.cache/xkcd. Location can be overridden
with ``XKCD_CACHE_DIR``.

2.0
===

Drop support for Python 3.5.

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.3
===

Comic searches now search the full text of the comics.

1.2.1
=====

Fix pmxbot usage to use keyword parameters.

1.2
===

Automated testing and deployment.
